INVALID_CONFIRMATION_CODE = 'invalid_confirmation_code'
SITE_WITH_DOMAIN_DOES_NOT_EXIST = 'site_with_domain_does_not_exist'
INCORRECT_PHONE_NUMBER = 'incorrect_phone_number'
INCORRECT_CONFIRMATION_PIN = 'incorrect_confirmation_pin'
EMAIL_ALREADY_REGISTERED_ON_DOMAIN = 'email_already_registered_on_domain'
PHONE_NUMBER_ALREADY_REGISTERED_ON_DOMAIN = 'phone_number_already_registered_on_domain'
INVALID_PASSWORD = 'invalid_password'
CREDENTIAL_NOT_CONFIRMED = 'credential_not_confirmed'
USER_WITH_PROVIDED_CREDENTIALS_DOES_NOT_REGISTERED_ON_SPECIFIED_DOMAIN = 'user_with_provided_credentials_does_not_registered_on_specified_domain'
TOO_FREQUENT_SMS_REQUESTS = 'too_frequent_sms_requests'
INVALID_PHONE_NUMBER = 'invalid_phone_number'
INVALID_OTP = 'invalid_otp'
INVALID_CREDENTIAL = 'invalid_credential'
INVALID_CREDENTIAL_TYPE = 'invalid_credential_type'
ATTEMPTS_LIMIT_REACHED = 'attempts_limit_reached'
INVALID_SMS_TYPE = 'invalid_sms_type'
PHONE_NUMBER_NOT_CONFIRMED = 'phone_number_not_confirmed'

# Google Sign-In error codes
GOOGLE_SIGN_IN_NOT_CONFIGURED = 'google_sign_in_not_configured'
INVALID_GOOGLE_ID_TOKEN = 'invalid_google_id_token'
INVALID_GOOGLE_AUTH_TEMP_TOKEN = 'invalid_google_auth_temp_token'
GOOGLE_AUTH_TEMP_TOKEN_EXPIRED = 'google_auth_temp_token_expired'

# Validator error codes
INVALID_EMAIL = 'invalid_email'
FIELD_IS_REQUIRED = 'field_is_required'
PASSWORD_TOO_SHORT = 'password_too_short'
PASSWORD_TOO_COMMON = 'password_too_common'
PASSWORD_ENTIRELY_NUMERIC = 'password_entirely_numeric'
PASSWORD_TOO_SIMILAR = 'password_too_similar'
